@@ -2,8 +2,6 @@ import random
 import base64
 import typing
 
-T = typing.TypeVar("T")
-
 _lowercase = "abcdefghijklmnopqrstuvwxyz"
 _uppercase = "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
 _numbers = "0123456789"
@@ -21,7 +19,7 @@ def gen_password(
     min_number: int = 1,
     min_specials: int = 1,
 ):
-    """ generate password for any resource
+    """generate password for any resource
 
     >>> len(gen_password(20))
     20
@@ -68,17 +66,14 @@ def gen_string(letters: str, length: int):
     return "".join([random.choice(letters) for i in range(length)])
 
 
-def first(l: typing.List[T]) -> T:
-    if len(l) == 0:
+def first(arr: typing.List[typing.Any]) -> typing.Any:
+    if len(arr) == 0:
         return None
-    return l[0]
+    return arr[0]
 
 
 def b64encode(s: str) -> str:
-    """
-
-    >>> b64encode("foobar42")
-    'Zm9vYmFyNDI='
+    """base64 encode
 
     :param str s: input string
     :return: base64 string
@@ -87,10 +82,7 @@ def b64encode(s: str) -> str:
 
 
 def b64decode(s: str) -> str:
-    """
-
-    >>> b64decode("Zm9vYmFyNDI=")
-    'foobar42'
+    """base64 decode
 
     :param str s: base64 string
     :return: output string
